# Hello World

This is an example project demonstrating how to publish a python module to PyPI.

## Installation

Run the following to install:

```python
pip install helloworld-judy2k
```

## Usage

```python
from helloworld import say_hello

# Generate "Hello, World!"
say_hello()

# Generate "Hello, Everybody!"
say_hello("Everybody")
```
